Module duration

Module duration 

A duration is a unit of time that represents the amount of time required to complete a task.

Structs

PositiveDuration
A duration is a unit of time that represents the amount of time required to complete a task.

Enums

DurationError
Represents an error that occurs when trying to parse a negative duration.

Constants

MAX_DURATION
Maximum duration allowed is ~31.68809 years.