pub enum DurationError {
NegativeDuration,
ExceedsMaximumDuration,
InvalidInput,
}Expand description
Represents an error that occurs when trying to parse a negative duration.
Variants
NegativeDuration
Used when the wanted duration would be negative.
ExceedsMaximumDuration
Used when the wanted duration would exceed the maximum allowed value.
InvalidInput
Used when trying to parse an invalid string.