pub struct NonNegativeDuration(/* private fields */);Expand description
A duration is a unit of time that represents the amount of time required to complete a task.
Implementations
Sourceimpl NonNegativeDuration
impl NonNegativeDuration
Sourcepub fn parse_from_str(s: &str) -> Result<Self, DurationError>
pub fn parse_from_str(s: &str) -> Result<Self, DurationError>
Tries to parse a string and return the corresponding [NonNegativeDuration]
Arguments
s- The string to parse. Currently, only hours are supported in the format “X h”.
Returns
Ok(NonNegativeDuration)- If the input string could be parsed into aNonNegativeDuration.Err(DurationError)- If the input string couldn’t be parsed into aNonNegativeDuration.
Errors
DurationError::InvalidInput- If the input string couldn’t be parsed into aNonNegativeDuration.
Examples
use planter_core::duration::NonNegativeDuration;
let duration = NonNegativeDuration::parse_from_str("8 h").unwrap();
assert_eq!(duration.num_hours(), 8);Trait Implementations
Sourceimpl Clone for NonNegativeDuration
impl Clone for NonNegativeDuration
Sourcefn clone(&self) -> NonNegativeDuration
fn clone(&self) -> NonNegativeDuration
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for NonNegativeDuration
Sourceimpl Debug for NonNegativeDuration
impl Debug for NonNegativeDuration
Sourceimpl Default for NonNegativeDuration
impl Default for NonNegativeDuration
Sourcefn default() -> NonNegativeDuration
fn default() -> NonNegativeDuration
Returns the “default value” for a type. Read more
Sourceimpl Deref for NonNegativeDuration
impl Deref for NonNegativeDuration
Sourceimpl Display for NonNegativeDuration
impl Display for NonNegativeDuration
impl Eq for NonNegativeDuration
Sourceimpl FromStr for NonNegativeDuration
impl FromStr for NonNegativeDuration
Sourceimpl Ord for NonNegativeDuration
impl Ord for NonNegativeDuration
Sourcefn cmp(&self, other: &NonNegativeDuration) -> Ordering
fn cmp(&self, other: &NonNegativeDuration) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for NonNegativeDuration
impl PartialEq for NonNegativeDuration
Sourcefn eq(&self, other: &NonNegativeDuration) -> bool
fn eq(&self, other: &NonNegativeDuration) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for NonNegativeDuration
impl PartialOrd for NonNegativeDuration
impl StructuralPartialEq for NonNegativeDuration