pub struct PositiveDuration(/* private fields */);Expand description
A duration is a unit of time that represents the amount of time required to complete a task.
Implementations
Sourceimpl PositiveDuration
impl PositiveDuration
Sourcepub fn parse_from_str(s: &str) -> Result<Self, DurationError>
pub fn parse_from_str(s: &str) -> Result<Self, DurationError>
Tries to parse a string and return the corresponding [PositiveDuration]
Arguments
s- The string to parse. Currently, only hours are supported in the format “X h”.
Returns
Ok(PositiveDuration)- If the input string could be parsed into aPositiveDuration.Err(DurationError)- If the input string couldn’t be parsed into aPositiveDuration.
Errors
DurationError::InvalidInput- If the input string couldn’t be parsed into aPositiveDuration.DurationError::ExceedsMaximumDuration- If the parsed duration exceeds the maximum allowed value.
Panics
This function uses expect, but it should only panic in case of a bug.
Examples
use planter_core::duration::PositiveDuration;
let duration = PositiveDuration::parse_from_str("8 h").unwrap();
assert_eq!(duration.num_hours(), 8);ⓘ
use planter_core::duration::PositiveDuration;
/// Passing invalid input will result in an `[DurationError::InvalidInput]`
let duration = PositiveDuration::parse_from_str("random garbage").unwrap();Trait Implementations
Sourceimpl Clone for PositiveDuration
impl Clone for PositiveDuration
Sourcefn clone(&self) -> PositiveDuration
fn clone(&self) -> PositiveDuration
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PositiveDuration
impl Debug for PositiveDuration
Sourceimpl Default for PositiveDuration
impl Default for PositiveDuration
Sourcefn default() -> PositiveDuration
fn default() -> PositiveDuration
Returns the “default value” for a type. Read more
Sourceimpl Deref for PositiveDuration
impl Deref for PositiveDuration
Sourceimpl Ord for PositiveDuration
impl Ord for PositiveDuration
Sourcefn cmp(&self, other: &PositiveDuration) -> Ordering
fn cmp(&self, other: &PositiveDuration) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for PositiveDuration
impl PartialEq for PositiveDuration
Sourceimpl PartialOrd for PositiveDuration
impl PartialOrd for PositiveDuration
Sourceimpl TryFrom<TimeDelta> for PositiveDuration
impl TryFrom<TimeDelta> for PositiveDuration
impl Copy for PositiveDuration
impl Eq for PositiveDuration
impl StructuralPartialEq for PositiveDuration