Module project

Module project 

A project is a set of activities required to transform ideas into reality. It is composed by tasks, team, stakeholders, resources and so on. It is usually divided into different phases: - Feasibility, where the project is evaluated to understand if the project is valid, and the organization is capable of delivering the expected outcome. - Design. Planning and analysis lead to the design of the project deliverable that will be developed. - Build. Construction of the deliverable with integrated quality assurance activities is conducted. - Test. Final quality review and inspection of deliverables are carried out before transition, go-live, or acceptance by the customer. - Deploy. Project deliverables are put into use and transitional activities required for sustainment, benefits realization, and organizational change management are completed. - Close. The project is closed, project knowledge and artifacts are archived, project team members are released, and contracts are closed. Depending on the kind of project (adaptive, predictive, hybrid), these phases can occur one after the other sequentially or in a loop. In a predictive approach, each phase comes right after the previous one. In an adaptive approach, there are blocks of planning, design, build that go one after the other, until the project is done. At the end of each iteration (sprint), there is feedback on the work done, and a prioritisation of the backlog.

Structs

Project
Represents a project with a name and a list of resources.
ProjectBuilder
Use builder syntax to set the inputs and finish with build().
SubtaskRelationship
A given task, might be composed of different subtasks.

Enums

ResourceConversionError
Represents an error that can occur when trying to convert Material resources variants to another variant.
TimeRelationship
The predecessor - successor relationship between tasks.