pub enum ResourceConversionError {
ResourceNotFound,
ConversionNotPossible,
}Expand description
Represents an error that can occur when trying to convert Material resources variants to another variant.
Variants
ResourceNotFound
Used when trying to convert a resource with an index out of bounds.
ConversionNotPossible
Used when trying to convert a resource that’s not a material, for example personnel.