pub enum TimeRelationship {
StartToFinish,
FinishToFinish,
FinishToStart,
StartToStart,
}Expand description
The predecessor - successor relationship between tasks.
Variants
StartToFinish
The predecessor has to start for the successor to finish.
FinishToFinish
The predecessor has to start for the successor to finish.
FinishToStart
The predecessor has to finish for the successor to start.
StartToStart
The predecessor has to start for the successor to finish.