Module resources

Module resources 

A resource is a material required in the project to carry out tasks and provide deliverables. Resources have a cost, the sum of which, will concur with the total cost of the project. Project team members can also be considered resources.

Structs

Consumable
Represents a consumable material resource that can be used in a project.
NonConsumable
Represents a non-consumable material resource that can be used in a project.

Enums

Material
Represents a material resource that can be used in a project. It can be either consumable or non-consumable.
Resource
Represents a resource that can be used in a project. A resource can be either a material or personnel.