pub enum Resource {
Material(Material),
Personnel {
person: Person,
hourly_rate: Option<u16>,
},
}Expand description
Represents a resource that can be used in a project. A resource can be either a material or personnel.
Variants
Material(Material)
Represents a material resource that can be used in a project.
Personnel
Represents a personnel resource. Personnel is usually a resource that can complete tasks