pub struct Consumable { /* private fields */ }Expand description
Represents a consumable material resource that can be used in a project.
Implementations
Sourceimpl Consumable
impl Consumable
Sourcepub fn new(name: impl Into<String>) -> Self
pub fn new(name: impl Into<String>) -> Self
Creates a new consumable material resource with the given name.
Example
use planter_core::resources::{Consumable, Material};
let consumable = Consumable::new("Steel".to_owned());
let material = Material::Consumable(consumable);
assert_eq!(material.name(), "Steel");Trait Implementations
Sourceimpl Clone for Consumable
impl Clone for Consumable
Sourcefn clone(&self) -> Consumable
fn clone(&self) -> Consumable
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Consumable
impl Debug for Consumable
Sourceimpl Default for Consumable
impl Default for Consumable
Sourcefn default() -> Consumable
fn default() -> Consumable
Returns the “default value” for a type. Read more
impl Eq for Consumable
Sourceimpl From<Consumable> for NonConsumable
impl From<Consumable> for NonConsumable
Sourcefn from(value: Consumable) -> Self
fn from(value: Consumable) -> Self
Converts to this type from the input type.
Sourceimpl From<NonConsumable> for Consumable
impl From<NonConsumable> for Consumable
Sourcefn from(value: NonConsumable) -> Self
fn from(value: NonConsumable) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for Consumable
impl PartialEq for Consumable
impl StructuralPartialEq for Consumable