NonConsumable

Struct NonConsumable 

pub struct NonConsumable { /* private fields */ }
Represents a non-consumable material resource that can be used in a project.

Implementations

Source

impl NonConsumable

pub fn new(name: impl Into<String>) -> Self

Creates a new non-consumable material resource with the given name.

Example
use planter_core::resources::{NonConsumable, Material};

let non_consumable = NonConsumable::new("Drill".to_owned());
let material = Material::NonConsumable(non_consumable);
assert_eq!(material.name(), "Drill");
pub const fn hourly_rate(&self) -> Option<u16>

Returns the hourly rate of the non-consumable material.

Example
use planter_core::resources::NonConsumable;

let non_consumable = NonConsumable::new("Steel".to_owned());
assert_eq!(non_consumable.hourly_rate(), None);
pub const fn update_hourly_rate(&mut self, hourly_rate: u16)

Updates the hourly_rate of the non consumable material.

Example
use planter_core::resources::NonConsumable;

let mut non_consumable = NonConsumable::new("Steel".to_owned());
non_consumable.update_hourly_rate(3);
assert_eq!(non_consumable.hourly_rate(), Some(3));
pub const fn remove_hourly_rate(&mut self)

Remove the cost per unit of the non consumable material.

Example
use planter_core::resources::NonConsumable;

let mut non_consumable = NonConsumable::new("Steel".to_owned());
non_consumable.update_hourly_rate(3);
assert_eq!(non_consumable.hourly_rate(), Some(3));
non_consumable.remove_hourly_rate();
assert_eq!(non_consumable.hourly_rate(), None);