pub enum Stakeholder {
Individual {
person: Person,
description: Option<String>,
},
Organization {
name: String,
description: Option<String>,
},
}Expand description
Stakeholders are all those individuals, organizations or entities who have an interest in the project. Their interest could be constructive or destructive.
Variants
Individual
A person who has an interest in the project.
Fields
Organization
An organization that has an interest in the project.