A task is a unit of work needed to achieve the project’s objectives. It can have a name, a description, a start and finish date, a duration, a completed flag, and resources assigned to it; it can also be nested into subtasks and related to other tasks in time.
Structs
- Task
- A task is a unit of work that can be completed by a person or a group of people. It can be assigned resources and can have a start, finish, and duration.