A duration is a unit of time that represents the amount of time required to complete a task.
Structs
- Positive
Duration - A duration is a unit of time that represents the amount of time required to complete a task.
Enums
- Duration
Error - Represents an error that occurs when trying to parse a negative duration.
Constants
- MAX_
DURATION - Maximum duration allowed is ~31.68809 years.