Material

Enum Material 

pub enum Material {
    Consumable(Consumable),
    NonConsumable(NonConsumable),
}
Represents a material resource that can be used in a project. It can be either consumable or non-consumable.

Variants



Consumable(Consumable)

A consumable resource is a material that needs to be resupplied after use.



NonConsumable(NonConsumable)

A non-consumable resource is a material that does not need to be resupplied after use.

Implementations

Source

impl Material

pub fn new(name: impl Into<String>) -> Self

Returns a consumable material by default, with the given name.

Example
use planter_core::resources::Material;

let material = Material::new("Steel".to_owned());
assert_eq!(material.name(), "Steel");
pub fn name(&self) -> &str

Returns the name of the material.

Example
use planter_core::resources::Material;

let material = Material::new("Steel".to_owned());
assert_eq!(material.name(), "Steel");
pub fn update_name(&mut self, name: impl Into<String>)

Updates the name of the material.

Example
use planter_core::resources::Material;

let mut material = Material::new("Steel".to_owned());
material.update_name("Iron".to_owned());
assert_eq!(material.name(), "Iron");
pub const fn quantity(&self) -> Option<u16>

Returns the quantity of materials.

Example
use planter_core::resources::Material;

let material = Material::new("Steel".to_owned());
assert_eq!(material.quantity(), None);
pub const fn update_quantity(&mut self, quantity: u16)

Updates the quantity of materials.

Example
use planter_core::resources::Material;

let mut material = Material::new("Steel".to_owned());
material.update_quantity(3);
assert_eq!(material.quantity(), Some(3));
pub const fn remove_quantity(&mut self)

Remove the quantity of materials.

Example
use planter_core::resources::Material;

let mut material = Material::new("Steel".to_owned());
material.update_quantity(3);
assert_eq!(material.quantity(), Some(3));
material.remove_quantity();
assert_eq!(material.quantity(), None);
pub const fn cost_per_unit(&self) -> Option<u16>

Returns the cost per unit of the material.

Example
use planter_core::resources::Material;

let material = Material::new("Steel".to_owned());
assert_eq!(material.cost_per_unit(), None);
pub const fn update_cost_per_unit(&mut self, cost_per_unit: u16)

Updates the cost per unit of the material.

Example
use planter_core::resources::Material;

let mut material = Material::new("Steel".to_owned());
material.update_cost_per_unit(3);
assert_eq!(material.cost_per_unit(), Some(3));
pub const fn remove_cost_per_unit(&mut self)

Remove the cost per unit of the material.

Example
use planter_core::resources::Material;

let mut material = Material::new("Steel".to_owned());
material.update_cost_per_unit(3);
assert_eq!(material.cost_per_unit(), Some(3));
material.remove_cost_per_unit();
assert_eq!(material.cost_per_unit(), None);