A task is a unit of work that needs to be completed in order to achieve the project’s objectives. Tasks have a duration, a start date, an end date, and a status.
Structs
- Task
- A task is a unit of work that can be completed by a person or a group of people. It can be assigned resources and can have a start, finish, and duration.