Task

Struct Task 

pub struct Task { /* private fields */ }
A task is a unit of work that can be completed by a person or a group of people. It can be assigned resources and can have a start, finish, and duration.

Implementations

Source

impl Task

pub fn new(name: impl Into<String>) -> Self

Creates a new task with the given name.

Arguments
  • name - The name of the task.
Returns

A new task with the given name.

Example
use planter_core::task::Task;

let task = Task::new("Become world leader");
assert_eq!(task.name(), "Become world leader");
pub fn edit_start(&mut self, start: DateTime<Utc>) -> Result<()>

Edits the start time of the task. If a duration is already set, the finish time will be updated accordingly. If there is a finish time set, but not a duration, the duration will be updated accordingly. The finish time will be pushed ahead if the start time is after the finish time.

Arguments
  • start - The new start time of the task.
Errors

Returns an error if the task has a finish date and the start date passed as parameter is too far from that.

Example
use chrono::{Utc, Duration};
use planter_core::task::Task;

let mut task = Task::new("Become world leader");
let start_time = Utc::now();
task.edit_start(start_time);
assert_eq!(task.start().unwrap(), start_time);
pub fn start(&self) -> Option<DateTime<Utc>>

Returns the start time of the task. It’s None by default.

Example
use chrono::{Utc};
use planter_core::task::Task;

let mut task = Task::new("Become world leader");
assert!(task.start().is_none());

let start_time = Utc::now();
task.edit_start(start_time);
assert_eq!(task.start().unwrap(), start_time);
pub fn edit_finish(&mut self, finish: DateTime<Utc>) -> Result<()>

Edits the finish time of the task. If there is a start time already set, duration will be updated accordingly. Start time will be pushed back if it’s after the finish time.

Arguments
  • finish - The new finish time of the task.
Errors

Returns an error if the task has a start date and the finish date passed as parameter is too far from that.

Example
use chrono::{Utc};
use planter_core::task::Task;

let mut task = Task::new("Become world leader");
assert!(task.start().is_none());

let mut finish_time = Utc::now();
task.edit_finish(finish_time).unwrap();
assert_eq!(task.finish().unwrap(), finish_time);
pub fn finish(&self) -> Option<DateTime<Utc>>

Returns the finish time of the task. It’s None by default.

Example
use chrono::{Utc};
use planter_core::task::Task;

let mut task = Task::new("Become world leader");
assert!(task.finish().is_none());
let finish_time = Utc::now();
task.edit_finish(finish_time);
assert_eq!(task.finish().unwrap(), finish_time);
pub fn edit_duration(&mut self, duration: PositiveDuration)

Edits the duration of the task. If the task has a start time, finish time will be updated accordingly.

Arguments
  • duration - The new duration of the task.
Example
use chrono::{Utc, Duration};
use planter_core::{task::Task, duration::PositiveDuration};

let mut task = Task::new("Become world leader");
task.edit_duration(Duration::minutes(30).try_into().unwrap());
assert!(task.duration().is_some());
assert_eq!(task.duration().unwrap(), Duration::minutes(30).try_into().unwrap());
pub fn add_resource(&mut self, resource: Resource)

Adds a Resource to the task.

Arguments
  • resource - The resource to add to the task.
Example
use planter_core::{resources::{Resource, Material, NonConsumable}, task::Task};

let mut task = Task::new("Become world leader");
let resource = Resource::Material(Material::NonConsumable(
  NonConsumable::new("Crowbar"),
));
task.add_resource(resource);

assert_eq!(task.resources().len(), 1);
pub fn resources(&self) -> &[Resource]

Returns the list of Resource assigned to the task.

Example
use planter_core::task::Task;
use planter_core::resources::{Resource, Material, NonConsumable};

let mut task = Task::new("Become world leader");
assert!(task.resources().is_empty());
let resource = Resource::Material(Material::NonConsumable(
  NonConsumable::new("Crowbar"),
));
task.add_resource(resource);
assert_eq!(task.resources().len(), 1);
pub fn edit_name(&mut self, name: impl Into<String>)

Edits the name of the task.

Arguments
  • name - The new name of the task.
Example
use planter_core::task::Task;

let mut task = Task::new("Become world leader");
task.edit_name("Become world boss");
assert_eq!(task.name(), "Become world boss");
pub fn name(&self) -> &str

Returns the name of the task.

Example
use planter_core::task::Task;

let mut task = Task::new("Become world leader");
assert_eq!(task.name(), "Become world leader");
pub fn edit_description(&mut self, description: impl Into<String>)

Edits the description of the task.

Arguments
  • description - The new description of the task.
Example
use planter_core::task::Task;

let mut task = Task::new("Become world leader");
task.edit_description("Description");
assert_eq!(task.description(), "Description");
pub fn description(&self) -> &str

Returns the description of the task.

Example
use planter_core::task::Task;

let mut task = Task::new("Become world leader");
task.edit_description("Description");
assert_eq!(task.description(), "Description");
pub fn completed(&self) -> bool

Whether the task is completed. It’s false by default.

Example
use planter_core::task::Task;

let mut task = Task::new("Become world leader");
assert!(!task.completed());
task.toggle_completed();
assert!(task.completed());
pub fn toggle_completed(&mut self)

Marks the task as completed.

Example
use planter_core::task::Task;

let mut task = Task::new("Become world leader");
assert!(!task.completed());
task.toggle_completed();
assert!(task.completed());
task.toggle_completed();
assert!(!task.completed());
pub fn duration(&self) -> Option<PositiveDuration>

Returns the duration of the task. It’s None by default.

Example
use chrono::{Utc, Duration};
use planter_core::task::Task;

let mut task = Task::new("Become world leader");
assert!(task.duration().is_none());

task.edit_duration(Duration::hours(1).try_into().unwrap());
assert!(task.duration().unwrap() == Duration::hours(1).try_into().unwrap());